<?php  namespace Concrete\Package\Janolaw\Src;

defined('C5_EXECUTE') or die("Access Denied.");

use Concrete\Core\Foundation\Object as Object;
use Concrete\Core\File\Service\File;
use Concrete\Core\Package\Package;

class Janolaw extends Object
{
	// Variables
	private $pkgConfig = false;
	private $janolaw_url = 'http://www.janolaw.de/agb-service/shops/%s/%s/%s/%s';
	private $langs = array(
		'de' => 'german',
		'gb' => 'english',
		'fr' => 'french'
	);
	private $types = array(
		'imprint' => 'Imprint',
		'datasecurity' => 'Data Security'
	);
	private $userId = 0;
	private $shopId = 0;
	
	// Getters
	public function getLangs() { return $this->langs; }
	public function getTypes() { return $this->types; }
	public function getUserId() { return $this->userId; }
	public function getShopId() { return $this->shopId; }
	
	// Constructor
	public function __construct() 
	{
		$pkg = Package::getByHandle('janolaw');
		$this->pkgConfig = $pkg->getConfig();		
		$this->userId = $this->pkgConfig->get('janolaw.user_id');
		$this->shopId = $this->pkgConfig->get('janolaw.shop_id');
	}
	
	/**
	 * Initialize update
	 * 
	 * @return boolean
	 */
	public function initUpdate()
	{
		$modified = $this->pkgConfig->get('janolaw.modified');
				
		if (time() > $modified) {
			$this->updateContent();
		}
		return true;
	}
	
	/**
	 * Update content in database
	 * 
	 */
	public function updateContent()
	{
		$langs = $this->getLangs();
		$types = $this->getTypes();
		
		foreach (array_keys($langs) as $lang) {
			foreach (array_keys($types) as $type) {
				$content = $this->getContent($type, $lang);
				if ($content) {
					$this->pkgConfig->save('janolaw.'.$type.'_'.$lang, $content);
					$this->pkgConfig->save('janolaw.modified', date('Y-m-d H:i:s', time()));
				}
			}
		}
	}
	
	/**
	 * Get remote content
	 * 
	 * @param type $type
	 * @param type $lang
	 * @return boolean
	 */
	public function getContent($type = 'imprint', $lang = 'de')
	{
		$lang = $lang == 'en' ? 'gb' : $lang;
		switch ($type) {
			case 'imprint':
				$content = 'legaldetails_include.html';
				break;

			case 'datasecurity':
				$content = 'datasecurity_include.html';
				break;
			
			default:
				$content = 'legaldetails_include.html';
				break;
		}
		
		$url = sprintf($this->janolaw_url, $this->getUserId(), $this->getShopId(), $lang, $content);
		
		$result = $this->download($url);
		
		if ($result && strlen($result) > 100) {
			return str_replace('style="text-align: center;"', '', $result);
		} else {
			return false;
		}
	}
	
	/**
	 * Get content via curl/File Helper
	 * 
	 * @param string $url
	 * @return array
	 */
	public function download($url)
	{
		$data = File::getContents($url);
		return $data;
	}
	
	/**
	 * Fetch content from database
	 * 
	 * @param type $type
	 * @param type $lang
	 * @return boolean
	 */
	public function getContentFromConfig($type = 'imprint', $lang = 'de')
	{	
		$lang = $lang == 'en' ? 'gb' : $lang;
		
		$pkg = Package::getByHandle('janolaw');
		$config = $pkg->getConfig();
		$data = $config->get('janolaw.'.$type.'_'.$lang);
		
		if (strlen($data) == 0) {
			return false;
		} else {
			return str_replace('style="text-align: center;"', '', $data);
		}
	}
}
